#
# spec file for package otrs (Version 2.2.6)
#
# Copyright (c) 2010 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#



Name:           otrs
Version:        2.2.6
Release:        46.3.1
License:        GPLv2+
Group:          Productivity/Networking/Email/Utilities
Url:            http://otrs.org/
AutoReqProv:    on
Requires:       apache2 apache2-mod_perl perl perl-DBI perl-GD perl-GDGraph perl-GDTextUtil perl-Digest-MD5 perl-Msql-Mysql-modules perl-Net-DNS perl-PDF-API2 mysql mysql-client fetchmail procmail
PreReq:         %insserv_prereq %fillup_prereq /usr/sbin/useradd /usr/sbin/usermod /bin/sed /bin/grep /bin/mv /bin/mkdir /bin/cat /bin/hostname /bin/mktemp /usr/bin/getent /usr/bin/basename apache2
Source:         ftp://ftp.otrs.org/pub/otrs/%{name}-%{version}.tar.bz2
Source1:        sysconfig.otrs
Source2:        otrs.README.en
Source3:        otrs.README.de
Patch:          otrs-init.diff
Patch1:         otrs-nochown.diff
Patch2:         otrs-2.2-OSA-2010-01.diff
Summary:        Open Ticket Request System
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  pwdutils
%define otrsdoc_dir_files CHANGES COPYING CREDITS INSTALL README* TODO UPGRADING doc
%if %ul_version >= 1
	%define	VENDOR UnitedLinux
%else
%if "%_vendor" == "suse"
	%define	VENDOR SUSE
%else
	%define	VENDOR %_vendor
%endif
%endif

%description
OTRS is an open source ticket request system with many features to
manage customer telephone calls and e-mails. It is distributed under
the GNU General Public License (GPL) and tested on Linux, Solaris, AIX,
FreeBSD, and Mac OS 10.x. If you receive many e-mails and want to
answer them with a team of agents, OTRS is a tool that can help.

Feature list:

Web interface:

* Agent Web interface for viewing and working on all customer
   requests

* Admin Web interface for changing system settings

* Customer Web interface for viewing and sending information to the
   agents

* Web interface with themes support

* Multilanguage support (Bulgarian, Dutch, English, Finnish, French,
   German, and Spanish)

* Independent customization of the output template's (dtl) release

* Web interface with attachment support

* Easy and logical use

E-Mail Interface:

* MIME support (attachments)

* PGP support

* SMIME support

* Dispatch of incoming e-mail via e-mail address or x-header

* Autoresponders for customers by incoming e-mail (per queue)

* E-mail notification to the agent by new tickets, follow-ups, or
   lock time-outs

Ticket:

* Custom queue view and queue view of all requests

* Ticket locking

* Ticket replies (standard responses)

* Ticket autoresponders per queue

* Ticket history, evolution of ticket status, and actions taken on
   ticket

* Ability to add notes (with different note types) to a ticket

* Ticket zoom feature

* Tickets can be bounced or forwarded to other e-mail addresses

* Ticket can be moved to a different queue (this is helpful if
   e-mails have a specific subject)

* Ticket priority

* Ticket time accounting

* Content full text search

System:

* Creation and configuration of user accounts and groups

* Creation of standard responses

* Signature configuration per queue

* Salutation configuration per queue

* E-mail notification of administrators

* E-mail notification sent to problem reporter (by create, locked,
   deleted, moved, and closed)

* Submitting update-info (via e-mail or web interface)

* Deadlines for trouble tickets

* ASP (active service providing) support

* TicketHook freely setable like 'Call#', 'MyTicket#', 'Request#' or
   'Ticket#'

* Ticket number format freely setable

* Different levels of permissions and access rights

* XML layer to support different SQL databases (like MySQL,
   PostgreSQL, Oracle, and DB2)

* User authentication against database or ldap directory

* Easy development of custom add-ons (OTRS API)

* Easy creation of different front-ends (for example: X Window
   System, console)

* A fast and useful application



Authors:
--------
    Carsten Gross <carsten at siski.de>
    Christian Schoepplein <cs at otrs.com>
    Franz Breu <breu.franz at bogen.net>
    Fred van Dijk <fvandijk at marklin.nl>
    Lars Mller <lmuelle at samba.org>
    Nicolas Goralski <ngoralski at oceanet-technology.com>
    Richard Kammermayer <rk at otrs.com>
    Stefan Rother <sr at otrs.com>
    Thomas Raith <tr at otrs.com>
    Vladimir Gerdjikov <gerdjikov at gerdjikovs.net>
    Martin Edenhofer <me at otrs.com>

%prep
%setup
%patch -p1
%patch1
%patch2
find -name ".cvsignore" -type f | xargs rm -fv

%build
/usr/sbin/useradd -r -d /opt/otrs -s /bin/false -c "OTRS System User" -g nogroup otrs 2>/dev/null || :
# copy config file
cp -a Kernel/Config.pm.dist Kernel/Config.pm
cd Kernel/Config/
for file in *.dist
do
	cp -a $file `basename $file .dist`
done
cd ../../
# copy all crontab dist files
for file in var/cron/*.dist
do
mv $file var/cron/`basename $file .dist`
done
rm INSTALL.RedHat
mv INSTALL.SuSE INSTALL

%install
[ "${RPM_BUILD_ROOT}" != "/" -a -d ${RPM_BUILD_ROOT} ] && rm -rf ${RPM_BUILD_ROOT}
export DESTROOT="/opt/otrs/"
mkdir -p \
	${RPM_BUILD_ROOT}/etc/init.d \
	${RPM_BUILD_ROOT}/etc/apache2/conf.d \
	${RPM_BUILD_ROOT}/etc/sysconfig \
	${RPM_BUILD_ROOT}/${DESTROOT}/ \
	${RPM_BUILD_ROOT}/%{_sbindir} \
	${RPM_BUILD_ROOT}/var/adm/fillup-templates
cp -a . ${RPM_BUILD_ROOT}/${DESTROOT}
for configFile in .fetchmailrc .mailfilter .procmailrc; do
	touch ${RPM_BUILD_ROOT}/${DESTROOT}/${configFile}
done
# install README
for lang in en de; do
	cp -p "${RPM_SOURCE_DIR}/otrs.README.${lang}" "README.%VENDOR.${lang}"
done
# remove files that are part of the docdir
pushd ${RPM_BUILD_ROOT}/${DESTROOT}
rm -rf %{otrsdoc_dir_files}
popd
# install sysconfig file and init script
install -m 644 ${RPM_SOURCE_DIR}/sysconfig.otrs $RPM_BUILD_ROOT/%{_var}/adm/fillup-templates/
install -m 755 scripts/suse-rcotrs ${RPM_BUILD_ROOT}/etc/init.d/otrs
ln -fs ../../etc/init.d/otrs ${RPM_BUILD_ROOT}/%{_sbindir}/rcotrs
# set permission
${RPM_BUILD_ROOT}/opt/otrs/bin/SetPermissions.sh ${RPM_BUILD_ROOT}/opt/otrs otrs wwwrun nogroup www echo
#chgrp -R root ${RPM_BUILD_ROOT}/opt/otrs
#chgrp -R www ${RPM_BUILD_ROOT}/opt/otrs/var/log
%if %suse_version > 930
otrs_apache_conf="scripts/apache2-httpd-new.include.conf"
%else
otrs_apache_conf="scripts/apache2-httpd.include.conf"
%endif
cp -p ${otrs_apache_conf} ${RPM_BUILD_ROOT}/etc/apache2/conf.d/otrs.conf

%preun
%stop_on_removal otrs
:

%pre
# Are we in update mode?
if [ ${1:-0} -gt 1 ]; then
	# Set new OTRS homedir and initial group for old installations
	getent passwd otrs | grep /opt/OpenTRS >/dev/null && \
		usermod -d /opt/otrs -g nogroup otrs
fi
/usr/sbin/useradd -r -d /opt/otrs -s /bin/false -c "OTRS System User" -g nogroup otrs 2>/dev/null || :

%post
# fill otrs sysconfig file
%{fillup_and_insserv otrs}
# Function to add content to a sysconfig variable
function modifySysconfigContent()
{
	SYSCONFIG_FILE=$1; REPLACE_CMD=$2
	TMP_FILE_BASENAME=$( basename "${SYSCONFIG_FILE}")
	test -d /dev/shm && \
		TMP_BASE_DIR="/dev/shm" || \
		TMP_BASE_DIR="/var/tmp"
	TMPFILE=$( mktemp "${TMP_BASE_DIR}/${TMP_FILE_BASENAME}-otrs-rpmpost-sysconfig.XXXXXX")
	if [ $? -ne 0 ]; then
		echo "Can't create temp file, ${TMPFILE}, to execute 'sed \"${REPLACE_CMD}\" \"${SYSCONFIG_FILE}\"'."
		return
	fi
	chmod --reference="${SYSCONFIG_FILE}" "${TMPFILE}"
	eval "sed ${REPLACE_CMD} \"${SYSCONFIG_FILE}\"" >"${TMPFILE}" && \
		mv "${TMPFILE}" "${SYSCONFIG_FILE}" || \
		echo "Can't execute 'sed \"${REPLACE_CMD}\" \"${SYSCONFIG_FILE}\"'."
}
# Return a sed command to replace or add a value
function createSedCmd2modifyValue()
{
	SYSCONFIG_FILE=$1; VARIABLE_NAME=$2; NEW_SETTING=$3; MODE=$4
	CURR_SETTING=""
	. "${SYSCONFIG_FILE}"
	case "${MODE}" in
		replace)
			test "${!VARIABLE_NAME}" = "${NEW_SETTING}" && return
			;;
		*|add)
			for value in ${!VARIABLE_NAME}; do
				test "${value}" = "${NEW_SETTING}" && return
				CURR_SETTING="${CURR_SETTING}${value} "
			done
			;;
	esac
	echo -en "-e \"s+^${VARIABLE_NAME}.*$+${VARIABLE_NAME}=\\\"${CURR_SETTING}${NEW_SETTING}\\\"+\""
}
# Remove /opt/otrs/scripts/apache2-httpd.include.conf and add
# /opt/otrs/scripts/apache2-httpd{,-new}.include.conf to
# APACHE_CONF_INCLUDE_FILES and add perl to APACHE_MODULES.
SYSCONFIG_FILE="/etc/sysconfig/apache2"
if test -e ${SYSCONFIG_FILE}; then
	VARIABLE_NAME="APACHE_CONF_INCLUDE_FILES"
%if %suse_version > 930
	OLD_SETTING="/opt/otrs/scripts/apache2-httpd.include.conf"
	/usr/sbin/sysconf_addword -r "${SYSCONFIG_FILE}" "${VARIABLE_NAME}" "${OLD_SETTING}" >/dev/null
	/usr/sbin/a2enmod perl >/dev/null
%else
	VARIABLE_NAME="APACHE_MODULES"
	NEW_SETTING="perl"
	SED_CMDS=$( createSedCmd2modifyValue "${SYSCONFIG_FILE}" "${VARIABLE_NAME}" "${NEW_SETTING}" add)
	test "${SED_CMDS}" && \
		modifySysconfigContent "${SYSCONFIG_FILE}" "${SED_CMDS}"
%endif
fi
# if rpm is not in update mode
if ! [ ${FIRST_ARG:-0} -gt 1 ]; then
	if [ -z "${YAST_IS_RUNNING}" ]; then
		for lang in LC_ALL LC_MESSAGE LANG; do
			test "${!lang}" && break
		done
		echo
		case "${!lang}" in
			de_*)
				echo "Hinweise zur Erstkonfiguration von OTRS finden Sie in"
				echo "/usr/share/doc/packages/otrs/README.%{VENDOR}.de"
				;;
			*)
				echo "About the initial setup of OTRS, please read"
				echo "/usr/share/doc/packages/otrs/README.%{VENDOR}.en"
				;;
		esac
		echo
	fi
fi
exit 0

%postun
%restart_on_update otrs
%insserv_cleanup

%clean
rm -rf ${RPM_BUILD_ROOT}

%files
%defattr(-,root,root)
%dir /etc/apache2
%dir /etc/apache2/conf.d
%config /etc/apache2/conf.d/otrs.conf
/etc/init.d/otrs
/usr/sbin/rcotrs
%doc %{otrsdoc_dir_files}
%{_var}/adm/fillup-templates/sysconfig.otrs
%defattr(-,wwwrun,root)
%config(noreplace) /opt/otrs/Kernel/Config.pm
/opt/otrs/Kernel/Config.pm.dist
/opt/otrs/Kernel/Config/Files
%config(noreplace) /opt/otrs/Kernel/Config/GenericAgent.pm
/opt/otrs/Kernel/Config/GenericAgent.pm.*
%config(noreplace) %attr(660,otrs,www) /opt/otrs/var/log/TicketCounter.log
%ghost %config(noreplace) %attr(-,otrs,root) /opt/otrs/.procmailrc
%ghost %config(noreplace) %attr(-,otrs,root) /opt/otrs/.fetchmailrc
%ghost %config(noreplace) %attr(-,otrs,root) /opt/otrs/.mailfilter
%attr(-,wwwrun,root) /opt/otrs/.fetchmailrc.dist
%attr(-,wwwrun,root) /opt/otrs/.mailfilter.dist
%attr(-,wwwrun,root) /opt/otrs/.procmailrc.dist
%config(noreplace) /opt/otrs/Kernel/Output/HTML/Standard/*.dtl
%config(noreplace) /opt/otrs/Kernel/Output/HTML/Lite/*.dtl
%config(noreplace) /opt/otrs/Kernel/Language/*.pm
%config(noreplace) %attr(-,otrs,root) /opt/otrs/var/cron/*
%dir %attr(-,otrs,root) /opt/otrs
%dir /opt/otrs/Kernel
%dir /opt/otrs/Kernel/Config
%dir /opt/otrs/Kernel/Output
%dir /opt/otrs/Kernel/Output/HTML
%dir /opt/otrs/Kernel/Output/HTML/Lite
%dir /opt/otrs/Kernel/Output/HTML/Standard
%dir /opt/otrs/Kernel/Language
%dir %attr(-,otrs,root) /opt/otrs/var
%dir %attr(-,otrs,root) /opt/otrs/var/cron
%dir %attr(770,otrs,www) /opt/otrs/var/log
%dir %attr(-,otrs,root) /opt/otrs/var/pics
/opt/otrs/ARCHIVE
/opt/otrs/RELEASE
/opt/otrs/Kernel/Config/Defaults.pm
/opt/otrs/Kernel/Language.pm
/opt/otrs/Kernel/Modules/
/opt/otrs/Kernel/Output/HTML/*.pm
/opt/otrs/Kernel/System/
/opt/otrs/bin/
%attr(-,otrs,root) /opt/otrs/bin/DeleteSessionIDs.pl
%attr(-,otrs,root) /opt/otrs/bin/UnlockTickets.pl
%attr(-,otrs,root) /opt/otrs/bin/otrs.getConfig
/opt/otrs/scripts/
%attr(-,otrs,root) /opt/otrs/var/logo-otrs.png
%attr(-,otrs,root) /opt/otrs/var/article/
%attr(-,otrs,root) /opt/otrs/var/httpd/
%attr(-,wwwrun,root) /opt/otrs/var/sessions/
%attr(-,otrs,root) /opt/otrs/var/spool/
%attr(-,otrs,root) /opt/otrs/var/tmp/
%attr(-,otrs,root) /opt/otrs/var/pics/stats/
/opt/otrs/Kernel/cpan-lib*

%changelog
* Wed Jul  7 2010 lmuelle@suse.de
- Fix OTRS-Core against possible SQL-Injection; OSA-2010-01; (bnc#576066).
* Thu Oct 16 2008 ro@suse.de
- drop needsrootforbuild
* Thu Aug 28 2008 cthiel@suse.de
- fix init script
* Mon Mar 31 2008 lmuelle@suse.de
- Update to version 2.2.6.
  + Bug #2650 - Mails isn't completely imported by PostmasterPOP3.pl
  + Bug #2758 - non-latin filenames (e. g. koi8-r, utf8, cp1251) in emails are
    not shown correctly.
  + Bug #2462 - Permission is denied when trying to print ticket details from
    customer panel (customer.pl).
  + Bug #2541 - Added missing "Ticket unlock" link for ticket for the followin
    actions 'Phone call', 'Merge', 'Move' and 'Forward'.
  + Bug #1957 - Auto reply for new Phone-Tickets replies to non- Existing
    addresses (if no email address is given in 'From' field).
  + Bug #1975 - Cannot forward email with .eml files as attachment.
  + Bug #2413 - Cannot write to BLOB column in table XML_STORAGE with DB2.
  + Bug #2255 - SysConfig setting Ticket -> Frontend::Customer::Ticket::
    ViewZoom -> Ticket::Frontend::CustomerTicketZoom###State has no effect
    (only closed is shown any time).
  + Bug #954  - Ticket split should link tickets automatically (origin to new
    one).
* Mon Mar 31 2008 lmuelle@suse.de
- SOAP authentications allows to get remote access without valid SOAP
  user; OSA-2008-01; CVE-2008-1515; [bnc#372382].
* Wed Jan 30 2008 lmuelle@suse.de
- Update to version 2.2.5.
  + Fixed bug# 2645 - SLA selection doesn't change when customer is
    changed.
  + Fixed bug# 2157 - Ticket merged note not translated.
  + Fixed bug# 2392 - Charset problems with iso8859 and the
    xml-caching mechanism.
  + Implemented workaround for bug# 2227 - XMLHashSearch returns
    no values on MS SQL in certain cases.
  + Fixed bug# 2330 - Cron.sh start <OTRS_USER> does not work.
  + Fixed bug# 977 - No agent notification for new ticket from
    webinterface if CustomerGroupSupport is enabled.
  + Fixed bug# 2621 - Wrong order of items (Subject,Service,SLA,Body
  - > Service,SLA,Subject,Body) in Frontend AgentTicketPhone,
    AgentTicketEmail and CustomerTicketMessage.
  + Fixed bug# 1687 - Wrong "New message!" hint on queue with
    "Customer State Notify" activated.
  + Fixed bug# 2613 - Images are broken in Lite-Theme if OTRS do
    not use the default Alias /otrs-web/.
  + Fixed bug# 2609 - Temp files are not removed after process was
    finished under windows.
  + Fixed bug# 2601 - Only agents with rw permissions are shown in
    inform agent selection of a note screen (note permission need to be
    activated via SysConfig first). Now all agents with _note_
    permissions are displayed.
  + Fixed bug# 2600 - MS SQL: Fulltext search in ticket body with
    mssql backend not possible (workaround, improved API for 2.3.x).
  + Fixed bug# 1120 - TO recipients which were sometimes dropped
    in a ticket reply.
  + Fixed bug# 2589 - Ticket-title not shown in ticket list of
    change customer, phone- and email ticket.
  + Fixed bug# 1148 - Lost of attachments when spliting ticket.
  + Fixed bug# 2295 - Added workaround for IE7. Tries to download
    [ Attachments ] or [ Attachments <-> Responses ].
  + Fixed bug# 2580 - Wrong quoating of semicolon if mssql is used.
  + Fixed bug# 2539 - SMIME signing was broken for private keys that
    have no passphrase and when openssl is unable to write to random
    state file.
  + Fixed bug# 2581 - Follow up not possible if "ticket#: xxxxxxx"
    is copied from webinterface into new email subject.
  + Fixed bug# 2479 - Unable to retrieve attachments bigger than
    3MB (on Oracle DB). Changed default read size from 4 MB to 15 MB in
    Kernel/System/DB/oracle.pm:
  + Fixed bug# 1428 - Whitespaces remove from email subject
    (notification and new tickets creation) if utf-8 is used
    (specifically in Russian, Chinese  and Japanese).  The problem is a
    bug in MIME::Tools/MIME::Words, for more info see CPAN-Bug# 5462:
    http://rt.cpan.org/Public/Bug/Display.html?id=5462 As solution
    Kernel/cpan-lib/MIME/Words.pm got patched. Note: Everybody who is
    not using Kernel/cpan-lib/ need to wait till this bug is fixed in
    official MIME::Tools/MIME::Words releases.
  + Fixed bug# 2166 - Probem with HTML-mails sent by MS Outlook
    2003 - "&#8211;" / long dash gets not decoded.
  + Fixed bug# 2377 - Missing translation in
    AdminCustomerUserService mask.
  + Fixed bug# 2537 - Unable to set free time fields.
  + Fixed bug# 2498 - A wrong sum of requests was shown in the
    performance log.
  + Fixed bug# 2482 - IntroUpgradePre in .opm files is not working
    on upgradinging via online repository.
- Update to version 2.2.4.
  + Fixed bug# 2477 - Escalation time calculation (destination time of
    escalation) is not working if host system is running in
    summertime/wintertime mode (loops because system is changing system
    time from 3:00 am to 2:00 am).
  + Fixed bug# 2474 - Config option UserSyncLDAPAttibuteGroupsDefination
    and UserSyncLDAPAttibuteRolesDefination is not working.
  + Fixed small typo in scripts/database/otrs-initial_insert.xml, for
    escalation notification text.
  + Fixed bug# 2473 - Not able to update existing cache files of
    customer user backend because of file permission problems (cache
    files are created with 644). From now on cache files are created
    with 664 permissions.
  + Fixed bug# 2472 - Emails in utf8 are not sent correctly (problem
    after upgrading Kernel/cpan-lib/MIME/*.pm).
  + Fixed bug# 2446 - Subject is not quoted.
  + Fixed bug# 2442 - Disappearing ticket free time checkboxes in
    some ticket masks after mask reloads.
  + Fixed bug# 2436 - Translation bug in the frontend function
    BuildSelection().
  + Fixed bug# 2289 - Compress with bzip2 dont works in backup.pl.
  + Fixed bug# 2421 - If customer cache backend is used, sometimes
    "Need Value" appears in the log file.
  + Fixed bug# 1203 - Changed Redhat shm workaround to use a fixed
    IPCKey per instance, but prevent clash with IPCKey of other instances.
  + Fixed bug# 2263 - Problems with array refs and escaping
  + Fixed bug# 2410 - $/ as given is currently unsupported at
    Kernel/cpan-lib/MIME/Decoder/NBit.pm line 140. We updated the CPAN
    module MIME-tools to version 5.423 to solve the problem.
  + Fixed bug# 2404 - Wrong results if you use StatsTypeID as
    TicketSearch attribute.
  + Fixed bug# 2407 - Performance handicap because of a missing
    'if'-attribute.
  + Fixed bug# 2404 - Problems with the time extended feature in
    stats module.
  + Fixed bug# 2398 - Translate the stats output.
  + Fixed bug# 2388 - Show the radio button of static stats files.
  + Fixed bug# 2383 - IntroInstallPre in .opm files is not working
    on installing via online repository.
  + Fixed bug# 2380 - Ignore HTMLQuote param in Layout object
    function _BuildSelectionOptionRefCreate.
  + Fixed bug# 2375 - Possible race condition in generic agent
    jobs (during processing jobs). Generic agent job attributes can get
    lost.
  + Fixed bug# 2276 - GenericAgent with SLA-Search fails, Service
    and SLA options are missing.
  + Fixed bug# 2360 - No Permission in customer panel after
    selecting ticket. Reason is, sender type is customer and article
    type is email-internal which is set via a postmaster filter.
  + Fixed bug# 2346 - Emty entries are shown in the responsible
    option list in TicketSearch mask.
  + Fixed bug# 2321 - It's not possible to use ñ or ü in
    description tag of .sopm file -> leading to perl syntax error!
  + Fixed bug# 2291 - Only include/use PDF::API2 in
    Kernel/Modules/AgentTicketSearch.pm and Kernel/Modules/AgentStats.pm
    if needed, to increase performance.
- Update to version 2.2.3.
  + Fixed bug# 2285 - Typo in german translation
    "Aktualisierungszeit".
  + Fixed bug# 1203 - Redhat shm workaround should not relate to
    real shm request.
  + Fixed bug# 2265 - On IIS6, Package Manager is displaying a
    error after installing a package (header not complete). But package got
    installed corectly.
  + Fixed bug# 2261 - False params in call of ServiceLookup() and
    SLALookup() functions.
  + Fixed reopened bug# 2142 - Ticket history entry was wrong if
    service, sla or ticket type was changed.
  + Fixed bug# 2193 - Postmaster module
    Kernel::System::PostMaster::Filter::NewTicketReject is not working -
    need Charset!
  + Fixed bug# 2245 - Responsible / Owner Field not working for
    all users in the Email-Ticket form.
  + Fixed Ticket# 2007082842000477 - Problem with different customer
    sources and use CacheTTL option (namespace of cache is not uniq).
  + Fixed Ticket# 2007082842000413 - Ticket created over phone
    ticket with state closed is shown in queue view like "My Queues (1)"
    but no ticket is shown if I click on "My Queues (1)" (if
    Kernel::System::Ticket::IndexAccelerator::StaticDB is used as
    Ticket::IndexModule).
  + Fixed bug# 2230 - OTRS on IIS - redirect/loop problem after
    login.
  + Fixed bug# 2229 - Return value of "ServiceLookup" is used
    without quoting in SQL statements.
  + Fixed bug# 2207 - translation failure in customer preferences
    (QueueView refresh time).
  + Fixed bug# 2214 - .opm Package can not handle &lt;, &gt; and
    &amp; in .sopm files.
  + Fixed bug# 2203 - OTRS will not create/verify correct pgp
    signs if utf8 is used.
  + Fixed bug# 2202 - Kernel::System::Email::SMTP is sending
    "localhost.localdomain" in smtp hello, some server rejecting this
    ("Host not found").
  + Fixed bug# 2024 - Problem with agent authentication via LDAP
    with ADS-Groups and content of DN like "Some\, Name".
  + Fixed bug# 2094 and 2143 - 'Got no MainObject' warning in
    Kernel/System/Crypt.pm
  + Fixed bug# 2192 - Useless fragments of old escalation mechanism
    produces errors.
  + Fixed bug# 1908 - Removed duplicate history entry for ticket
    subscribe action.
  + Fixed bug# 1492 - Fixed typo in Kernel/Language.pm.
  + Fixed bug# 2160 - 0 was ignored in database insert by package
    building.
  + Fixed bug# 2156 - External customer database is not working,
    if it's configured the following error message appears
    ("Got no MainObject in Kernel/System/DB.pm line 85").
  + Fixed bug# 2155 - Std-Attachments are not usable in agent
    ticket compose screen (no std attachments are shown in compose
    screen).
  + Fixed bug# 2118 - Fixed typo in german translation file (
    Kernel/Language/de.pm).
  + Fixed bug# 2117 - Fixed small typo in initial insert files.
  + Fixed bug# 1999 - Service and SLA can not changed on an
    existing ticket.
  + Fixed bug# 2142 - If a service or a sla of a ticket was changed,
    no ticket history entry was added.
  + Fixed bug# 2135 - scripts/DBUpdate-to-2.2.2.sql contains wrong
    SQL. Not the queue table needs to be changed, the ticket table would
    be the right one.
  + Fixed bug# 2134 - PDF print is creating damaged pdf files with
    PDF::API2 0.56 or smaller.
  + Fixed bug# 940 - After owners unlock ticket and a follow-up
    arrives the system, all agents which selected the queue of this
    ticket get and follow up message. In this follow up message the name
    was always the current owner and not the recipient of the email
    (which should be).
  + Fixed bug# 2001 - New escalation times and the responsible are
    not shown in any print views.
- Update to version 2.2.2.
  + Fixed bug# 2114 - Fixed the problems with the email object.
  + Fixed bug# 2053 - If core "System::Permission" note is used,
    not effect to the ticket note mask appears.
  + Fixed bug# 2059 - config setting $Self->{'Database::Connect'}
    is not overwriting default option used by driver.
  + Fixed bug# 2105 - Notification after moving a ticket to my
    queues is wrong -> ">OTRS_CUSTOMER_QUEUE<" got not replaced in
    subject.  SQL files scripts/database/otrs-initial_insert.*.sql got
    fixed.
  + Fixed bug# 2029 - Selected responsible agent was not taken
    over after creating a phone ticket.
  + Fixed bug# 1946 - Setting of service, sla or type via email
    X-OTRS-Service, X-OTRS-SLA or X-OTRS-Type header not possible.
  + Fixed bug# 2097 - Sometimes problems with SMTP module and utf8
    to send emails.
  + Fixed bug# 2061 - UserSyncLDAPMap does not work properly after
    upgrade to 2.2. The reason is, that we cleaned up this config option
    and the new one from Kernel/Config/Defaults.pm need to be used. We
    also added an check which log that an old config setting is used
    (also an compat.  feature to still use the old option has been
    added).
  + Fixed bug# 2068 - Date problem with non en installations of
    MSSQL server. Some date inserts or package installations failed.
    Added database init connect option to mssql driver ("SET DATEFORMAT
    ymd" / Kernel/System/DB/mssql.pm).
  + Because of safety reason, generic agent jobs will not longer run
    without min. one search attribute (admin interface and cmd). So if
    you want to match all ticket, you need to add an * in the ticket
    number.
  + Fixed bug# 2021 - Errors in MSSQL post schema files.
  + Fixed bug# 2025 - No upgrade PostgreSQL possible, added missing
    lines in DBUpdate-to-2.2.postgresql.sql.
  + Fixed Ticket#2007072342000148 - Old OTRS (< OTRS 2.2)
    attachments are corrupt after upgrade if file backend is used.
  + Updated portuguese translation, thanks Filipe Henriques and
    Rui Pires!
  + Updated norwegian translation, thanks to Fredrik Andersen!
  + Updated hungarian translation, thanks to Aron Ujvari!
  + Updated spanish translation, thanks to Carlos Oyarzabal!
  + Fixed bug# 2016 - CustomerUserUpdate: Add a function to handle
    empty values.
  + Fixed bug# 2047 - Add MainObject to the needed object check.
  + Fixed bug# 2045 - Notifications on reopen are not sent to
    owner/responsible.
  + Fixed bug# 2011 - Translation problems in stats module.
- Update to version 2.2.1.
  + Updated finnish translation, thanks to Mikko Hynninen!
  + Fixed bug# 1998 - Error with the web installer if no utf8
    database is selected.
  + Disabled only show escalated tickets in queue view because
    of already show escalation notifications.
  + Updated portuguese translation, thanks Filipe Henriques!
  + Fixed bug# 2000 - Typo in database update script
    DBUpdate-to-2.1.mysql.sql.
  + Reworked AdminCustomerUserService mask.
  + Fixed wildcard handling in ServiceSerarch().
  + Added option to log sql queries which take longer the 4 sek.
    and can be enabled via Kernel/Config.pm (Database::SlowLog). For
    more info see Kernel/Config/Defaults.pm.
  + Fixed not working alter table to SET or DROP NULL and NOT
    NULL via xml interface (Kernel/System/DB/postgresql.pm).
  + Updated french translation, thanks to Yann Richard and Remi Seguy!
  + Updated netherlands translation, thanks to Richard Hinkamp!
  + Updated hungarian translation, thanks to Aron Ujvari!
  + Updated russian translation, thanks to Andrey Feldman!
  + Updated greek translation, thanks to Stelios Maistros!
- Update to version 2.2.0 rc1.
  + Fixed bug# 1941 - Ticket Escalation blocks QueueView even if
    Agent has only read access.
  + Fixed bug# 1951 - Changed default selection of 'valid' field in
    AdminService and AdminSLA mask.
  + Added feature (bug# 1949 an 1950) for customer ldap backend
    for soft or hard die.
  + Fixed bug# 1927 - It is possible to uninstall a required
    package.
- Update to version 2.2.0 beta4.
  + Fixed bug in service and sla tables. Column comment was wrongly
    defined as required field.
  + Fixed bug# 1894 - otrs.addUser does not work
  + Fixed bug# 1913 - Added missing columns first_response_time,
    solution_time and rename column escalation_time to update_time for
    table queue in DBUpdate-to-2.2.oracle.sql.
  + Remove wrong item in check needed stuff section of SLAList()
    function.
  + Update german translation.
  + Sync HTML style of admin masks. No functionality changed.
  + Fixed double ContentType in ArticleAttachment() of attachment
    backends (Kernel/System/Ticket/ArticleStorage(DB|FS).pm).
  + Sync of all configurable frontend modules. No functionality
    changed.
  + Fixed bug# 1898 - Invalid services and slas was shown in agent
    masks.
  + Fixed bug# 1866 - Error while DB upgrade from 2.1.5 to 2.2.0
    beta3.
  + Ingresed width of html login tables from 270 to 280 because
    of new language selection.
  + Fixed bug# 1825 - SQL ticket_history INSERT syntax error in
    HistoryAdd().
  + Fixed bug# 1840 - Repeat escalation message when queue, SLA
    Solution time is shown.
- Update to version 2.2.0 beta3.
  + Fixed bug# 1773 - DB-error in phone ticket if sla but no
    service is selected.
  + Fixed bug# 1035 - OTRS does not set encoding for the mysql
    database connection (i.e. UTF-8).
  + Fixed bug# 1778 - Config option Database::Connect should be
    possible.
  + Fixed bug# 1611 - Now the Statsmodule use the mirror db if
    configured.
  + Fixed bug# 1809 - Fixed typo in variable name (PrioritiesStrg ->
    PriotitiesStrg).
  + Fixed bug# 1670 - If no result the generation of pie graph throws
    error.
  + Fixed bug# 1769 - If I change the ticket SLA, the history is
    not relfecting this change.
  + Fixed bug# 1768 - If I change the ticket service, the history
    is not relfecting this change.
- Update to version 2.2.0 beta2.
  + Fixed bug# 1448 - Apache::Registry in README.webserver wrong,
    mod_perl2 is missing.
  + Fixed bug# 1286 - apache configuration should use
    <IfModule mod_perl.c>.
  + Fixed bug# 1755 - Wrong permissions for some files.
  + Fixed bug# 1757 - Cannot install postgres db - null value in
    column "escalation_start_time" violates not-null constraint.
  + Fixed bug# 1745 - Invalid SQL-statements in AgentTicketQueue
    view.
  + Fixed bug# 1741 - "PostmasterFollowUpStateClosed" buggy on
    follow up actions.
  + Updated bulgarian translation, thanks to Alex Kantchev!
  + Fixed bug# 1748 - Session not allowed to be larger than 358400
    Bytes using IPC. Change max session size from 350k to 2 MB.
  + Fixed bug# 1744 - Unable to create xml_storage table in utf8
    charset on mysql database.
  + Fixed bug# 1739 - Unable to insert new SLA via admin-web after
    upgrade to 2.2.0 beta1.
- Update to version 2.2.0 beta1.
  + Fixed not shown optional ticket free time option fields in
    customer panel.
  + Fixed bug# 1017 - script initial_insert.sql, ampersand and oracle.
  + Fixed enhacement bug# 1668 - removed unnecessary dependency for
    fetchmail from .srpms.
  + Fixed bug# 1398 - Malformed UTF-8 charaters in Admin Backend -
    System Log.
  + Fixed bug-ticket# 2007020542000593 - Queue refresh "off"
    can't be used on oracle database.
  + Fixed Free Field output in AgentTicketForward and
    AgentTicketPhoneOutbound.
- Update to version 2.1.8.
  + Fixed bug# 2134 - PDF print is creating damaged pdf files with
    PDF::API2 0.56 or smaller.
  + fixed bug# 2046 - german Umlauts not printed in PDFs if system
    runs in utf-8 mode. The PDF::API2 corefonts (which are used as
    default) doesn't support UTF-8. Changed the used fonts from
    PDF::API2 corefonts to the DejaVu true type fonts. Add config
    options to use other true type fonts.
  + fixed bug# 1926 - package manager ignore PackageRequired tags
    in OPM files.
* Sun Jun 10 2007 ro@suse.de
- remove requires for mysql-shared
* Thu May 10 2007 lmuelle@suse.de
- Update to version 2.1.7.
  + fixed bug# 1551 - decode_mimewords() in ArticleWriteAttachment()
    dies due to utf-8
  + updated Kernel/Language/pt_BR.pm translation file - Thanks
    to Fabricio Luiz Machado!
  + fixed bug# 1650 - crypt/sign bug in AgentTicketCompose screen
  + fixed bug# 1659 - Uploading and Saving Pictures in MSSQL won't
    work with bigger Files (~700KB)
  - >MSSQL ONLY<- You also need to change some tables by using: ->MSSQL ONLY<-
    ALTER TABLE web_upload_cache ALTER COLUMN content TEXT NOT NULL;
    ALTER TABLE article_plain ALTER COLUMN body TEXT NOT NULL;
    ALTER TABLE article_attachment ALTER COLUMN content TEXT NOT NULL;
    ALTER TABLE article ALTER COLUMN a_body TEXT NOT NULL;
    ALTER TABLE standard_response ALTER COLUMN text TEXT NOT NULL;
    ALTER TABLE standard_attachment ALTER COLUMN content TEXT;
    ALTER TABLE sessions ALTER COLUMN session_value TEXT;
    ALTER TABLE xml_storage ALTER COLUMN xml_content_value TEXT;
    ALTER TABLE package_repository ALTER COLUMN content TEXT NOT NULL;
  + fixed upload cache problem in win32 with .pdf files
  + fixed bug# 1228 - Apostrophe not valid in email address.
  + fixed bug# 1442 and 1559 - ArticleFreeKey and ArticleFreeText
    default selection does not work.
  + fixed ticket# 2007031242000149 - session backend fails to insert
    sessions bigger the 4k on oracle database backend
  + fixed bug# 1671 - restore.pl fails with "Got no LogObject"
  + fixed bug# 1115 - HTML error in NewTicket Customer's interface
  + fixed bug# 1658 - Subqueues of Queues with brackets are not
    shown in the QueueView
  + added rpm packages for Fedora Core 4, 5 and 6 to auto build
    service
  + fixed ticket# 2007022342000586 - attachment problem with oracle
    backend if utf-8 is used
  + fixed database driver if 0 is used in begining of an xml insert
- Changes of version 2.1.6.
  + fixed bug #1504 - Ticket Creation fails with DB2 due to
    character quoting issues
  + fixed bug #1506 - Error creating Tickets in DB2 due to conflict
    in string/numerical comparison
  + fixed bug #1445 - OTRS is not encoding Umlauts correctly in
    Organization email header
  + fixed bug #1548 - submitting AgentTicketPhone or
    AgentTicketEmail form without queueid leads to broken fields
  + fixed bug #1581 - Garbled paths containing domain names
  + updated Mail::Tools from 1.60 to 1.74 - fixed bug #1642 -
    Cant get mails via PostmasterPop3.pl - Unrecognised line
  + fixed bug #1545 - Wrong Variableusage in $Self->{PageShown}
    (Kernel/Modules/AgentTicketMailbox.pm)
  + fixed bug #1291 - Download link in SysConfig skips config
    options -> now download link will be shown if no changes are done
  + fixed bug #1097 - Disabling Bounce Feature via SysConfig does
    not work properly
  + fixed ticket #2007022242000293 hard line rewrap of body content
    in frontend modules
  + improved speed of SysConfig core module, added cache mechanism
    (it's about 2 times faster)
  + fixed ticket #2007022042000288 - error on creating postmaster
    filter on oracle database
  + fixed not working crypt/sign option in AgentTicketCompose mask
  + fixed bug #980 - Use of uninitialized value in
    Kernel/System/AuthSession/FS.pm
  + changed unlock time reset mechanism, added unlock time reset
    if a agent sends an external message to the customer (like escalation
    reset mechanism)
  + fixed bug in _XMLHashAddAutoIncrement() - function could not
    return keys greater than '9'.
  + fixed bug #1056 - UTF-8 mode of OTRS and German Umlaute within
    agent's name
  + fixed bug #1505 - UserSyncLDAPMap fails with LDAP.pm version
    1.26 and up
  + fixed ticket_watcher.user_id datatype, moved from BIGINT to
    INTEGER
  + fixed oracle driver for xml alter table actions
  + improved _CryptedWithKey() - private key detection of
    Kernel/System/Crypt/PGP.pm if more keys are used for crypted messages
  + fixed ArticleFreeText output in CustomerTicketZoom mask
  + fixed bug in agent- and customer-ticket print feature
- Changes of version 2.1.5.
  + fixed ignored ticket responible in phone ticket
  + fixed DestinationTime() if calendar feature is used
  + fixed not working freetime fields
  + fixed not working time selection if time zone feature is used
  + fixed not working email notification tags in auto response,
    agent and customer email notifications
  + fixed case sensitive of customer user login and agent user
    login in Kernel/System/User.pm and Kernel/System/CustomerUser/DB.pm if
    oracle or postgresql is used
  + fixed quoting in user selection if + is used in UserLogin in
    Kernel/Output/HTML/Standard/AdminCustomerUserForm.dtl
  + fixed bug #1532 - utf8 charsetproblems in stats
  + fixed bug #1446 - No "(Ticket unlock!)" link in
    AgentTicketCompose
  + fixed customer ldap auth if system is iso-8859 and ldap server
    is running in utf-8
  + fixed not working Kernel/System/DB/db2.pm (syntax error)
- Changes of version 2.1.4.
  + fixed not working free time selection in AgentTicketClose,
    AgentTicketNote, AgentTicketOwner, AgentTicketPending, AgentTicketPriority
    and AgentTicketResponsible
  + added config param for shown my queues/custom queues
    in preferences, default are shown all ro queues, see also
    PreferencesGroups###CustomQueue under Frontend::Agent::Preferences
  + fixed ldap sync of agents attributes - invalid agents
    are not longer synced to valid if ldap auth was successfully, the
    invalid agent will still be invalid
  + fixed bug #1187 - Escalation Notifications sent to invalid agent
  + improved link quote of long links in web interface
  + fixed bug #962 - Broken attachments with cyrillic filenames
  + fixed bug #1521 - Merge Feature
  + fixed bug #1523 - update of FreetextValues 9-16 not working
  + fixed bug #1524 - ticketFreeText Fields 9-16 not displayed
    at CustomerTicketPrint and CustomerTicketZoom
  + fixed bug #1359 - acl problem if '' is used in properties to match
  + fixed bug #1031 - scripts/backup.pl fails in mysqldump with
    encrypted database password
  + fixed bug #1378 - Got no MainObject! in bin/otrs.getTicketThread
  + fixed bug #1200 - not working TicketACL actions AgentTicketCompose,
    AgentTicketBounce, AgentTicketForward and AgentTicketPhoneOutbound
  + added log notice for switch to user admin feature
  + fixed bug #1210 - wrong calculation of Kernel::System::Time
    WorkingTime()
  + added changes notice of generic agent jobs to log sub
    system (to keep clear who changed the job)
  + moved ticket number generator loop check from 1000 to 6000
    (Kernel/System/Ticket/Number/*.pm)
  + fixed not working faq lookup in compose answer and forward
    screen
  + fixed double quoted "$Quote{"Cc: (%%s) added database email!""}
    in compose answer screen (Kernel/Modules/AgentTicketCompose.pm)
  + fixed bug #1498 - Typo in QuoteSingle, Kernel/System/DB/mssql.pm
  + moved Quote() from Kernel/System/DB.pm to db backend modules
    Kernel/System/DB/*.pm because of needed Quote() in xml processing
  + improved handling if there are double customer users in
    the database used by search result
  + fixed PGP/SMIME bug - Can't call method "body" on an undefined
    value at Kernel/System/EmailParser.pm line 382
  + fixed bug #1395 - utf-8 - ArticleStorage FS - Attachments with
    German Umlauts cant be downloaded
  + added config option Ticket::PendingNotificationOnlyToOwner
    to send reached reminder notifications of unlocked tickets only to ticket
    owner
  + fixed database driver detection/problem if a second database
    connect with different driver is used (wrong sql will not longer be
    generated) Note: old database driver files Kernel/System/DB/*.pm
    not longer compatible
  + added config option Ticket::ResponsibleAutoSet to set owner
    automatically as responsible if no responsible is set (default is 1)
* Mon Apr  9 2007 ro@suse.de
- build as root for now
* Tue Nov 21 2006 lmuelle@suse.de
- Update to 2.1.3.
  + removed not needed Reply-To of agent notifications
  + fixed missing \n on csv output of customer ticket search
  + fixed not working ticket free time option in phone ticket
  + added missing access permission pre check to show ticket menu items or not
  + fixed bug - not shown empty "-" selection of new onwer if on move if
  Ticket::ChangeOwnerToEveryone is set
  + update of Dansk language file, thanks to Mads N. Vestergaard
  + update of Spanish language file, thanks to Jorge Becerra
  + added AuthModule::HTTPBasicAuth::Replace and
  Customer::AuthModule::HTTPBasicAuth::Replace config option to HTTPBasicAuth
  modules to strip e. g. domains like example_domain\user from login down to
  user
  + added AuthModule::LDAP::UserLowerCase to allways convert usernames into
  lower case letters
  + added set auto time zone of agent/customer based on java script offset
  feature on every login
  + fixed not working all owner/responsible selection in phone view
  + read out CustomerUserSearchListLimit correctly if LDAP customer backend is
  in use
  + fixed always shown responsible selection
  + removed not needed default free text fields from phone outbound
  + fixed agent can be customer follow up feature
  + added possible - selection for next state in phone view outbount
  + fixed LDAP problems "First bind failed! No password, did you mean noauth or
  anonymous ?"
  + fixed double agent notifications on ticket move to queue and also selected
  owner
* Wed Oct 18 2006 lmuelle@suse.de
- Update to version 2.1.2.
  + switched to md5 check sum for password in user_preference table
  + fixed #1373 - RH RPM requires sendmail, but works with other MTAs
  + fixed double agent notifications on follow up if agent is
    owner and responible
  + fixed bug #1311 - Apostrophes are incorrectly displayed under
    IE 6 & IE7 but correctly displayed under Firefox 1.5.0.6  -=>
    moved from $Text{} to $JSText{} for text translations in Java Script parts
    to have a correct quoting
  + fixed not shown follow up feature in customer panel if ticket
    is closed
  + added missing customer print feature
  + fixed bug #1361 - Can't locate object method "ModGet" via
    package "Kernel::System::Config"
* Tue Oct 17 2006 lmuelle@suse.de
- Update to version 2.1.1
  + fixed bug #1213 - some errors not logger by LDAP backends
  + fixed bug #1248 - Ticket Zoom - Article Thread - Color of auto
    responses should be yellow
  + fixed bug #1323 - 2.1 DBUpgrade issue with PostgreSQL - patch
  + fixed bug #1333 - No reset of escalation time after follow-up
  + fixed bug #1345 - Attached binary files uploaded and saved to
    the FS are corrupted.
  + add ticketfreetext-, ticketfreetime- and articlefreetext support
    to pdf output
  + improved stats export/import with an id-name wrapper
  + fixed bug #1353/1354 changed autoreponse text
  + add transparency to some images
  + fixed bug #1358 - Customer History > All customer tickets.
    returns an incorrect number of tickets
  + fixed bug #1293 - Can't use an undefined value as a HASH
    reference at /opt/otrs/bin/cgi-bin//../../Kernel/Modules/AgentTicketBulk.pm
    line 194
  + fixed bug #1356 - mssql driver bug - Stats module of OTRS 2.1
    beta 2 - "Cant use string ("0")".
  + fixed bug #1335 - removed "uninitialized value" warning in
    NavBarTicketWatcher.pm
  + fixed opm check do not install/upgrade packages if one file to
    install already exists in an other package
  + added "-a exportfile" feature to bin/opm.pl to export files
    of a package into a defined directory e. g. "-d /path/to/"
  + removed Re: from agent notification emails
  + added change to remove 4 not needed empty spaces after folding
    of email headers (sometimes 4 empty spaces in subject appear)
  + updated pdf-logo to ((otrs))
  + added DBUpdate-to-2.1.oracle.sql to get oracle databases up to
    date
  + fixed double sending of note notifications
  + fixed link to email and phone after adding a new customer user
  + added fix to removed leading and trailing spaces in search
    fields of object linking
  + moved Frontend::ImagePath variable
  (/otrs-web/images/Standard/) from .dtl files to config option
  + added examples how to use SOAP (bin/cgi-bin/rpc.pl and
    scripts/rpc-example.pl)
  + added mulit calendar / queue support - you can use different
    time zones in different queues and each agent can select the own time zone
    NOTE: table queue need to be modified - see scripts/DBUpdate-to-2.1.*.sql
  + fixed bug #739 - in the login you can type something behind the
    pass and it works / added password md5 support (required Crypt::PasswdMD5
    from CPAN or from Kernel/cpan-lib/ - via "cvs update -d")
  + fixed $Quote{""} bug in login page
  + fixed bug #1284 - removed mysql dependence in
    scripts/apache-perl-startup.pl and scripts/apache2-perl-startup.sql
  + fixed bug #1282 - setting up a postgresql database fails
  + added performance log feature in admin interface to monitor
    your system page load performance over different times (1h, 3h, 9h, 1d, 2d,
    3d) - its disabled per default
  + removed Re: in subject auto response emails
  + added PDF output support to AgentTicketPrint module
  + fixed bug in pdf module - redesiged Table() to fix a lot of
    infinite loops
  + fixed bug in pdf module - special control characters produces
    infinite loops
  + added ldap attribute to groups/roles sync feature, so its
    possible to use user attributes for permission handling
  + fixed bug #1283 - test for modules executed in cronjobs
  + added cmd option for bin/opm.pl to find package of file
    e. g. bin/opm.pl -a file -p Kernel/System/FileA.pm
  + added sleep in bin/PostMasterPOP3.pl after 10 (2 sec) and
    25 (3 sec) emails on one stream (protect server against overload)
  + added PDF output feature for stats module and ticket search results
  + updated to cpan MIME::Tools 5.420
  + changed ticket escalation method, escalation start will
    be reseted after every "new" customer message and after agent
    communication to customer
  + added new link object functions and db table link_object changes
  + added <OTRS_CUSTOMER_DATA_*> tags to auto responses
  + added support of mssql database server (experimental)
  + added new feature to sync ldap groups into otrs roles
    (see more in Kernel/Config/Defaults.pm under UserSyncLDAPGroupsDefination
    and UserSyncLDAPRolesDefination)
  + new stats framework implemented :-)
  + fixed bug #1258 - changed language description from Traditional Chinese
    to Simplified Chinese
  + fixed bug #1151 - Error when changing customer on ticket in
  + improved performance of ticket search mask (in cases with
    over 500 Agents and over 50 Groups) by adding GroupMemberInvolvedList()
    and modify GroupMemberList(), GroupGroupMemberList(), GroupRoleMemberList()
    and GroupUserRoleMemberList() at Kernel/System/Group.pm
  + fixed bug #1132 - Wrong display of escalation time
  + fixed bug #1151 - Error when changing customer on ticket in
    TicketStatusView
  + added ticket watcher feature, per default it's disabled
  + fixed bug #1240 - Tickets not shown in "New messages" if
    Auto Response "Reply" is active
  + fixed bug #1206 - When no RELEASE file is available, no
    product and version is displaied and strange messages apear in the
    apache error log;  using standard values in this case now
  + added public frontend module to serve local repository as
    remote repository (accessable via IP authentication)
  + fixed bug #1154 - Problem in displaying pending tickets
    in agent mailbox
  + improved postmaster follow up detection by scanning email
    body, attachment and/or raw email (all is disabled by default)
  + fixed bug #1023 - Comma in From field creates multiple emails
    in webform.pl
  + fixed IE problem with image-buttons
    involved files: AdminSysConfigEdit.dtl and AdminSysConfig.pm
  + fixed format bug in Package Manager - PackageView
  + moved to read any language files located under
    Kernel/Language/xx_*.pm at each request to have any translated words
    e. g. for navigation bar available (Kernel/Language/xx_Custom.pm is
    still used as latest source file)
  + added config option to show ticket title in main header
    of frontend (e. g. QueueView, ZoomView and Mailbox)
  + moved from "otrs" to "otrs-x.x.x" directory in
    tar.gz / tar.bz download format
  + added article free text attrubutes
  + moved from Kernel::Output::HTML::Generic to
    Kernel::Output::HTML::Layout - all sub modules localted under
    Kernel/Output/HTML/Layout*.pm will ne loaded automatically
    at runtime
  + improved ticket zoom to shown attachments with
    html title about attachment info (name, size, ...)
  + added use of current config values in admin sysconfig
    fulltext search
  + fixed some spelling mistakes for the English original in
    language templates and language files
  + added admin init (Kernel/Modules/AdminInit.pm) to init
    config files .xml->.pm after a new setup (after inital root login)
  + splited Kernel::Modules::AgentTicketPhone into
    two modules Kernel::Modules::AgentTicketPhone and
    Kernel::Modules::AgentTicketPhoneOutbound (phone calls for existing
    tickets) also templates are renamed!
  + cleanup for ticket event names (added compat mode):
    TicketCreate, TicketDelete, TicketTitleUpdate, TicketUnlockTimeoutUpdate,
    TicketEscalationStartUpdate, TicketQueueUpdate (MoveTicket),
    TicketCustomerUpdate (SetCustomerData), TicketFreeTextUpdate
    (TicketFreeTextSet), TicketFreeTimeUpdate (TicketFreeTimeSet),
    TicketPendingTimeUpdate (TicketPendingTimeSet), TicketLockUpdate (LockSet),
    TicketStateUpdate (StateSet), TicketOwnerUpdate (OwnerSet),
    TicketResponsibleUpdate, TicketPriorityUpdate (PrioritySet), HistoryAdd,
    HistoryDelete, TicketAccountTime, TicketMerge, ArticleCreate,
    ArticleFreeTextUpdate (ArticleFreeTextSet), ArticleUpdate, ArticleSend,
    ArticleBounce, ArticleAgentNotification, (SendAgentNotification),
    ArticleCustomerNotification (SendCustomerNotification), ArticleAutoResponse
    (SendAutoResponse), ArticleFlagSet
  + added own X-OTRS-FollowUp-* header if Queue, State, Priority,
    ...  should be changed with follow up emails (see: doc/X-OTRS-Headers.txt)
  + reworked "config options" and "interface" of _all_ agent
    ticket interfaces to get is clear
  + replaced ticket config option "Ticket::ForceUnlockAfterMove"
    with ticket event module "Ticket::EventModulePost###99-ForceUnlockOnMove"
  + replaced ticket config option "Ticket::ForceNewStateAfterLock"
    with ticket event module "Ticket::EventModulePost###99-ForceStateChangeOnLock"
  + added "responsible" ticket feature!
    (db update with scripts/DBUpdate-to-2.1.(mysql|postgres).sql)
  + added persian translation (incl. TextDirection support)
  - Thanks to Amir Shams Parsa!
  + added default ticket event module to reset ticket owner
    after move action (it's disable per default)
  + added default next state in ticket forward
  + added OTRS_Agent_* tags like OTRS_Agent_UserFirstname and
    OTRS_Agent_UserLastname for salutation and signature templates
  + added update and insert via admin sql box
  + 'removed old compat files' Kernel/Config/Files/Ticket.pm
    and Kernel/Config/Files/TicketPostMaster.pm
  + added 8 more ticket free text fields
    (db update with scripts/DBUpdate-to-2.1.(mysql|postgres).sql)
  + added SendNoNotification option for MoveTicket(),
    LockSet() and OwnerSet() in Kernel/System/Ticket.pm (used in
    GenericAgent to do some admin stuff).
  + added online repository access for bin/opm.pl
  + added Delete and Spam config option to
    Kernel/Config/Files/Ticket.xml for Ticket::Frontend::MenuModule
  + added column type check in xml database defination
  + added unit test system
  + improved admin view of session management
  + moved FAQ from framework to own application module
    (can be installed over opm online repository now)
  + moved otrs archive directory for download and in RPMs
    from otrs to otrs-x.x.x
  + added multi pre application module support, just
    define it like:
    $Self->{PreApplicationModule}->{AgentInfo} = 'Kernel::Modules::AgentInfo';
  + fixed bug 1132 - Wrong display of escalation time
  + added missing utf-8 encoding in agent and customer auth
  + added missing utf-8 encoding customer user backend
  + changed language description from Traditional Chinese to
    Simplified Chinese (bug #1258)
  + fixed bug 1151 - Error when changing customer on ticket in
    TicketStatusView
  + fixed bug #1240 - Tickets not shown in "New messages" if
    Auto Response "Reply" is active
  + fixed bug #1206 - When no RELEASE file is available, no
    product and version is displaied and strange messages apear in the
    apache error log;  using standard values in this case now
  + fixed bug #1154 - Problem in displaying pending tickets
    in agent mailbox
  + fixed bug #1023 - Comma in From field creates multiple emails
    in webform.pl
  + added SUSE 10.x RPM support
  + fixed bug #925 - Binary Attachments incorrectly utf-8
    encoded in ticket replies
  + fixed links to new phone/email ticket after a new
    customer is created via Kernel/Modules/AdminCustomerUser.pm
  + update of Portuguese language file  - Thanks to
    Manuel Menezes de Sequeira)
  + added Greek translation - Thanks to Stelios Maistros!
  + fixed bug #991 - changed $Data{} to $QData{} in Ticket.xml
    and Ticket.pm config files to solve problem when answering requests
    that contain HTML tags
  + updated Dutch language file - Thanks to Richard Hinkamp!
  + added Slovak translation
  + fixed/removed die in Kernel/System/AuthSession/FS.pm
  - => GetSessionIDData() - not wanted to die if nn SessionID is given
  + added Danish translation - Thanks to Thorsten Rossner!
  + updated Norwegian translation - Thanks to Knut Haugen
  + fixed some spelling mistakes for the English original in
    language templates and language files
  + updated Brazilian Portuguese translation -Thanks to
    Fabricio Luiz Machado!
  + fixed missing translation after new ticket was created
  + added long month translation for calendar popup
  + changed Kernel/System/Spelling.pm to work with (a|i)spell
    on Windows systems
  + added <OTRS_TICKET_*> and <OTRS_CONFIG_*> support to
    auto respons templates
  + fixed/removed wrong config option
    "Ticket::Frontend::QueueSortDefault", added own config option for
    StatusView of tickets
  + fixed bug #1047 forward fails if " is in From
  + fixed ldap authentication if application charset is
    e. g. iso-8859-1 and not utf-8
  + fixed some spelling mistakes in
    Kernel/Config/Files/Ticket.xml and Kernel/Config/Files/Framework.xml
  + Added X-Spam-Level to config files to have the possibility
    to filter for this header with PostMasterFilter
  + fixed bug #1069 - Problem when the name of a GenericAgent
    job was updated
  + fixed PostMaster filter admin interface if wrong syntax
    regexp is used (don't save invalid regexp because not email can be
    received)
  + added bin/CheckSum.pl and also ARCHIVE file to include
    md5 sum archive of current distribution
  + improved PostMaster if no article can be created
  + fixed internal server error if in sysconfig search
  * is used
  + fixed "enter" submit bug in sysconfig (e. g. reset first
    item in the edit site)
  + fixed ArticleAttachmentIndex() - wrong index count in
    fs lookup - attachment icons sometimes not shown
  + added added missing class="button" in submit type="submit"
    of .dtl templates
  + fixed default note-type and default state-type in ticket
    pending mask
  + fixed stats/graph error message 'Can't call method "png"
    on an undefined value at ...'
  + fixed missing delete on time_accounting in
    Kernel/System/Ticket/Article.pm if article got deleted
  + improved die if xml is invalid in Kernel/System/XML.pm
  + added compat config option for compose answer to
    replace original sender with current customers email address
  + updated French language file, thanks to Yann Richard
  + fixed bug #1025 - ORA-01400: cannot insert NULL into ("OTRS"
    ."CUSTOMER_USER"."COMMENTS"
  + fixed bug #1018 - initial_insert.sql, oracle error ORA-01400:
    cannot insert NULL into
  + fixed std attachment feature (no attachment after
    additional fiel upload) in agent ticket compose
  + improved database Quote() for integer, also allow +|-
    in integer
  + fixed order of create attributes (TicketCreate(), TicketFreeTime(),
    TicketFreeTime(), ArticleCreate(), ...) on customer ticket creation
  + fixed bug #1010 - ORA-00972 Identifier is too long for oracle
  + fixed bug #1011 - ORA-01408: such column list already indexed,
    Oracle error
  + fixed wrong follow up notification (to all agents)
    via customer panel if ticket is already closed
  + updated Dutch language file, thanks to Richard Hinkamp
  + fixed not working -r option in scripts/backup.pl
    (-r == removed backups older then -r days)
  + remove leading and trailing spaces in ldap filter for
    agent and customer authentication
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Dec  1 2005 lmuelle@suse.de
- Update to 2.0.4; [#135006]; CVE-2005-3893, CVE-2005-3894, CVE-2005-3895.
* Wed Aug 31 2005 lmuelle@suse.de
- Add german translation of the README.SUSE.
- Remove /opt/otrs/scripts/apache2-httpd.include.conf and install
  /opt/otrs/scripts/apache2-httpd-new.include.conf to
  /etc/apache2/conf.d/; bugs.otrs.org [#904].
- Change OTRS_USED_WEBSERVER_RCSCRIPT default value to rcapache2.
- Remove extra %%post code for Apache 1 sysconfig settings.
* Tue Aug 23 2005 lmuelle@suse.de
- Update to 2.0.2.
* Mon Aug  1 2005 cthiel@suse.de
- update to 2.0.1-01
* Fri Jul 22 2005 lmuelle@suse.de
- Update to 2.0.0-beta6.
* Wed Dec  8 2004 lmuelle@suse.de
- Replace all apache occurrences by apache2 and add information to the
  README.SUSE to add "perl" to APACHE_MODULES; [#48857].
* Mon Dec  6 2004 lmuelle@suse.de
- Ensure to allow HTTP access to /otrs by default; [#48906].
- Use Apache 2 by default for OTRS_USED_WEBSERVER_RCSCRIPT; [#48904].
- Ensure %%preun returns with 0 even %%stop_on_removal otrs not; [#48858].
* Wed Oct 27 2004 lmuelle@suse.de
- Update to version 1.3.2.
* Sat Sep 25 2004 lmuelle@suse.de
- Update to version 1.3.1.
* Fri Jul 23 2004 ro@suse.de
- do not send a mail on installation
* Wed Jul 14 2004 lmuelle@suse.de
- Update to version 1.2.4.
- Add try-restart to the init script, stop_on_removal to preun and
  restart_on_udpate to postun.
* Mon Jun 14 2004 ro@suse.de
- requires: replace mod_perl with apache2-mod_perl
* Fri Apr  2 2004 lmuelle@suse.de
- update to version 1.2.3
* Tue Mar 16 2004 lmuelle@suse.de
- fix to paragraph 6 of the README
* Fri Mar  5 2004 lmuelle@suse.de
- update to version 1.2.2
- remove userdel from PreReq
* Thu Sep 18 2003 poeml@suse.de
- set permissions of files that need write access by both "otrs"
  user and "apache" user to group "www" [#29824]
- add a README, and send the mail to root only on first
  installation [#27211]
* Mon Sep  1 2003 mmj@suse.de
- Add sysconfig metadata [#28913]
* Sun Jun 22 2003 lmuelle@suse.de
- finaly remove userdel in %%postun
- add sanity checks while adding apache include file to the apache sysconfig
  file
- replace requires apache by http_daemon
* Fri Jun 20 2003 lmuelle@suse.de
- update to version 1.1.1
- add missing directories
- use mktemp im %%post; add /bin/mktemp to PreReq
- use getent passwd otrs in %%post
- temporarily disable userdel in the %%postun
* Tue Mar 18 2003 lmuelle@suse.de
- change group ownership for most files to root, #25543
- call hostname only if /etc/HOSTNAME exists and is greater than zero, #25495
* Tue Feb 18 2003 lmuelle@suse.de
- add separate binaries to PreReq
- add missing files and directories to %%files section
- add informational message on stdout if installed without YaST
* Tue Feb 18 2003 lmuelle@suse.de
- add patch to fix permission settings
- remove defattr from files section
* Mon Feb 17 2003 lmuelle@suse.de
- check if ${RPM_BUILD_ROOT} is not / in %%clean section
* Tue Feb 11 2003 lmuelle@suse.de
- update to version 1.0.1
* Tue Sep 17 2002 ro@suse.de
- removed bogus self-provides
* Tue Aug 20 2002 mmj@suse.de
- Correct PreReq
* Tue Aug  6 2002 kukuk@suse.de
- Fix Requires: perl-Syslog -> perl-Unix-Syslog
* Mon Aug  5 2002 kukuk@suse.de
- Remove perl-Digest-MD5/perl-MIME-Base64 from Requires, they are
  now part of main perl package.
* Thu Jun 13 2002 ro@suse.de
- always use macros when calling insserv
* Tue Mar 12 2002 kukuk@suse.de
- Create the new user as system account in the free range 100-499
* Wed Feb 20 2002 uli@suse.de
- initial package
